@@ -1,5 +1,5 @@
 # lpd FDS(Falling Detection Sensing)  - ISK Raw Data 
-# ver:0.1.0
+# ver:0.0.1
 # 2021/05/24
 # 
 # parsing lpd FDS -ISK
@@ -14,6 +14,7 @@
 #          (1)Output list data
 # v0.1.0 : 2021/05/024 
 #          (1)Output DataFrame
+# v0.1.1 : 2021/05/026 info modify
 #
 
 import serial
@@ -68,13 +69,13 @@ class LpdFDS:
 	
 	def __init__(self,port):
 		self.port = port
-		print("(jb)lpd Falling Detection Sensing(FDS) initial")
+		print("(jb)lpd Falling Detection Sensing initial")
 		print("(jb)vsersion:v0.1.0")
 		print("(jb)For Hardware:Batman-201(ISK)")
 		print("(jb)Hardware: IWR-6843")
 		print("(jb)Firmware: lpd-I471")
 		print("(jb)UART Baud Rate:921600")
-		print("Output: V6,V7,V8,V9 data:(RAW)")
+		print("Output: V6,V7,V8,V9 data: RAW Data or DataFrame")
 		
 	def useDebug(self,falseTrue):
 		self.dbg = falseTrue
@@ -161,7 +162,7 @@ class LpdFDS:
 		ll6 = pd.DataFrame(l6,columns=self.v6_col_names_rt)
 		ll7 = pd.DataFrame(l7,columns=self.v7_col_names_rt)
 		ll8 = pd.DataFrame(l8,columns=self.v8_col_names_rt)
-		ll9 = pd.DataFrame(l9,columns=self.v9_col_names_rt) #l9 #wait for implement
+		ll9 = pd.DataFrame(l9,columns=self.v9_col_names_rt)
 		return (dck,ll6,ll7,ll8,ll9)
 
 #
@@ -273,7 +274,9 @@ class LpdFDS:
 					#print(":".join("{:02x}".format(c) for c in sbuf))
 					try:
 						ttype,self.tlvLength = struct.unpack('2I', sbuf)
-						print("(TL)--tlvNum:{:d}: tlvCount({:d})-------ttype:tlvLength:v{:d}:{:d}".format(self.hdr.numTLVs,tlvCount,ttype,self.tlvLength))
+						if disp == True:
+							print("(TL)--tlvNum:{:d}: tlvCount({:d})-------ttype:tlvLength:v{:d}:{:d}".format(self.hdr.numTLVs,tlvCount,ttype,self.tlvLength
+							
 						if ttype not in typeList or self.tlvLength > 10000:
 							if self.dbg == True:
 								print("(TL)Improper TL Length(hex):(T){:d} (L){:x} numTLVs:{:d}".format(ttype,self.tlvLength,self.hdr.numTLVs))
